process

package
v0.2.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 22, 2025 License: BSD-2-Clause Imports: 10 Imported by: 0

README

Process

Package process implements a leader-worker process model & its control client.

A control client process connects to a leader process, tells or calls its cmdui APIs. The leader process starts and monitors its worker process. It uses a TCP connection to communicate with its worker process. A leader process has one worker process only.

If the webui interface of the leader process is open, you can access it through a web browser too.

If the leader process is connected to a Rockman, then its cmdui interface and webui interface will not be opened. In this case, it is managed by the Rockman.

Layout

Process uses these directories:

  • client/ - As client process,
  • common/ - Shared elements between client, leader, and worker,
  • leader/ - As leader process,
  • worker/ - As worker process.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Main

func Main(opts *Opts)

Main is the main() for client process, leader process, and worker process.

Types

type Opts added in v0.2.4

type Opts struct {
	ProgramName  string
	ProgramTitle string
	ProgramUsage string
	DebugLevel   int
	CmdUIAddr    string
	WebUIAddr    string
}

Opts is the options passed to Main() to customize its behavior.

Directories

Path Synopsis

Jump to